@@ -1,11 +1,10 @@
-from enum import Enum
 from os import system
 from random import randrange
 
 system("")
 
 
-class BGC(Enum):
+class BGC:
     BLACK = "\x1B[40m"
     RED = "\x1B[41m"
     GREEN = "\x1B[42m"
@@ -24,7 +23,7 @@ class BGC(Enum):
     WHITE = "\x1B[107m"
 
 
-class FGC(Enum):
+class FGC:
     BLACK = "\x1B[30m"
     RED = "\x1B[31m"
     GREEN = "\x1B[32m"
@@ -43,7 +42,7 @@ class FGC(Enum):
     WHITE = "\x1B[97m"
 
 
-class ACC(Enum):
+class ACC:
     RESET = "\x1B[0m"
     RELOAD = "\x1B[!p"
     CLEARSCREEN = "\x1Bc"
@@ -60,13 +59,13 @@ class ACC(Enum):
     ALTERNATIVE_BUFF = "\x1B[?1049h"
     ORIGINAL_BUFF = "\x1B[?1049l"
 
-    def TITLE(title):
+    def title(title):
         return f"\x1B]2;{title}\x07"
 
-    def RANDOMRGB(mode="Color"):
-        if mode not in ["Color", "gray"]:
-            mode = "Color"
-        if mode == "Color":
+    def rabdomrgb(self="Color"):
+        if self not in ["Color", "gray"]:
+            self = "Color"
+        if self == "Color":
             r, g, b = (
                 randrange(0, 255),
                 randrange(0, 255),
@@ -78,88 +77,83 @@ class ACC(Enum):
             b = r
         return f"\x1B[38;2;{r};{g};{b}m"
 
-    def RANDOMD():
+    def randomd(n):
         n = randrange(0, 255)
         return f"\x1B[38;5;{n}m"
 
-    def CUSTOMRGB(r, g, b):
+    def customrgb(r, g, b):
         return f"\x1B[38;2;{r};{g};{b}m"
 
-    def CUSTOMC(n):
+    def customc(n):
         return f"\x1B[38;5;{n}m"
 
-    def BCUSTOMRGB(r, g, b):
+    def bcustomrgb(r, g, b):
         return f"\x1B[48;2;{r};{g};{b}m"
 
-    def BCUSTOMC(n):
+    def bcustomc(n):
         return f"\x1B[48;5;{n}m"
 
 
-class MCC(Enum):
-    CURSOR_DBLINK = "\x1B[?12h"
-    CURSOR_EBLINK = "\x1B[?12l"
-    CURSOR_HIDE = "\x1B[?25l"
-    CURSOR_SHOW = "\x1B[?25h"
+class MCC:
+    cursor_dblink = "\x1B[?12h"
+    cursor_eblink = "\x1B[?12l"
+    cursor_hide = "\x1B[?25l"
+    cursor_show = "\x1B[?25h"
 
-    ERASE_NXT_WINDOW = "\x1B[0J"
-    ERASE_PRV_WINDOW = "\x1B[1J"
-    ERASE_ALL_WINDOW = "\x1B[2J"
-    ERASE_NXT_LINE = "\x1B[0K"
-    ERASE_PRV_LINE = "\x1B[1K"
-    ERASE_ALL_LINE = "\x1B[2K"
-    SET_TAB = "\x1BH"
-    DEL_TAB = "\x1B[0g"
-    RES_TAB = "\x1B[3g"
+    erase_nxt_window = "\x1B[0J"
+    erase_prv_window = "\x1B[1J"
+    erase_all_window = "\x1B[2J"
+    erase_nxt_line = "\x1B[0K"
+    erase_prv_line = "\x1B[1K"
+    erase_all_line = "\x1B[2K"
+    set_tab = "\x1BH"
+    del_tab = "\x1B[0g"
+    res_tab = "\x1B[3g"
 
-    def UP(count=1):
-        return f"\x1B[{count}A"
+    save_cursor = "\x1B[s"
+    load_cursor = "\x1B[u"
 
-    def DOWN(count=1):
-        return f"\x1B[{count}B"
+    def up(self=1):
+        return f"\x1B[{self}A"
 
-    def RIGHT(count=1):
-        return f"\x1B[{count}C"
+    def down(self=1):
+        return f"\x1B[{self}B"
 
-    def LEFT(count=1):
-        return f"\x1B[{count}D"
+    def right(self=1):
+        return f"\x1B[{self}C"
 
-    def ROW(count=1):
-        return f"\x1B[{count}G"
+    def left(self=1):
+        return f"\x1B[{self}D"
 
-    def CURSORPOSITION(x, y):
+    def row(self=1):
+        return f"\x1B[{self}G"
+
+    def cursor_position(x, y):
         return f"\x1B[{x};{y}H"
 
-    def SAVE_CURSOR():
-        return "\x1B[s"
+    def scroll_down(self=1):
+        return f"\x1B[{self}T"
 
-    def LOAD_CURSOR():
-        return "\x1B[u"
+    def scroll_up(self=1):
+        return f"\x1B[{self}S"
 
-    def SCROLL_DOWN(count=1):
-        return f"\x1B[{count}T"
+    def push_right(self=1):
+        return f"\x1B[{self}@"
 
-    def SCROLL_UP(count=1):
-        return f"\x1B[{count}S"
+    def erase_right(self=1):
+        return f"\x1B[{self}P"
 
-    def PUSH_RIGHT(count=1):
-        return f"\x1B[{count}@"
+    def replace_right(self=1):
+        return f"\x1B[{self}X"
 
-    def ERASE_RIGHT(count=1):
-        return f"\x1B[{count}P"
+    def push_down(self=1):
+        return f"\x1B[{self}L"
 
-    def REPLACE_RIGHT(count=1):
-        return f"\x1B[{count}X"
-
-    def PUSH_DOWN(count=1):
-        return f"\x1B[{count}L"
-
-    def ERASE_DOWN(count=1):
-        return f"\x1B{count}M"
-
-    def NEXT_TAB(count):
-        return f"\x1B{count}I"
-
-    def PREV_TAB(count):
-        return f"\x1B{count}Z"
+    def erase_down(self=1):
+        return f"\x1B{self}M"
 
+    def next_tab(self):
+        return f"\x1B{self}I"
 
+    def prev_tab(self):
+        return f"\x1B{self}Z"
